Resource

Struct Resource 

pub struct Resource { /* private fields */ }
A kind of resource.

Be careful: The documentation of Resource constants are based on a few systems. It may be inconsistent with other platforms.

References

Linux: https://man7.org/linux/man-pages/man2/getrlimit.2.html

FreeBSD: https://www.freebsd.org/cgi/man.cgi?query=getrlimit

NetBSD: https://man.netbsd.org/getrlimit.2

Implementations

Source

impl Resource

pub fn set(self, soft: u64, hard: u64) -> Result<()>

Set resource limits.

Errors

See setrlimit

pub fn get(self) -> Result<(u64, u64)>

Get resource limits.

Errors

See getrlimit

pub fn as_name(self) -> &'static str

Returns the name of the resource.

Example
assert_eq!(Resource::NOFILE.as_name(), "RLIMIT_NOFILE");
pub const fn available_names() -> &'static [&'static str]

Returns available resource names.

pub const fn available_resources() -> &'static [Self]

Returns available resources.

pub const fn as_raw(self) -> RawResource

Returns the raw resource type.

Be careful: The actual type of RawResource can be different on different platforms.

Source

impl Resource

pub const AS: Self

The maximum size (in bytes) of the process’s virtual memory (address space).

pub const CORE: Self

The maximum size (in bytes) of a core file that the process may dump.

pub const CPU: Self

A limit (in seconds) on the amount of CPU time that the process can consume.

pub const DATA: Self

The maximum size (in bytes) of the process’s data segment (initialized data, uninitialized data, and heap).

pub const FSIZE: Self

The maximum size (in bytes) of files that the process may create.

pub const LOCKS: Self

(early Linux 2.4 only)

A limit on the combined number of flock(2) locks and fcntl(2) leases that this process may establish.

pub const MEMLOCK: Self

The maximum number (in bytes) of memory that may be locked into RAM.

pub const MSGQUEUE: Self

A limit on the number of bytes that can be allocated for POSIX message queues for the real user ID of the calling process.

pub const NICE: Self

This specifies a ceiling to which the process’s nice value can be raised using setpriority(2) or nice(2).

pub const NOFILE: Self

This specifies a value one greater than the maximum file descriptor number that can be opened by this process.

pub const NPROC: Self

A limit on the number of extant process (or, more precisely on Linux, threads) for the real user ID of the calling process.

pub const RSS: Self

A limit (in bytes) on the process’s resident set (the number of virtual pages resident in RAM).

pub const RTPRIO: Self

This specifies a ceiling on the real-time priority that may be set for this process using sched_setscheduler(2) and sched_setparam(2).

pub const RTTIME: Self

A limit (in microseconds) on the amount of CPU time that a process scheduled under a real-time scheduling policy may consume without making a blocking system call.

pub const SIGPENDING: Self

A limit on the number of signals that may be queued for the real user ID of the calling process.

pub const STACK: Self

The maximum size (in bytes) of the process stack.