pub struct Resource { /* private fields */ }Expand description
A kind of resource.
Be careful: The documentation of Resource constants are based on a few systems.
It may be inconsistent with other platforms.
References
Linux: https://man7.org/linux/man-pages/man2/getrlimit.2.html
FreeBSD: https://www.freebsd.org/cgi/man.cgi?query=getrlimit
Implementations
Sourceimpl Resource
impl Resource
Sourcepub const fn available_names() -> &'static [&'static str]
pub const fn available_names() -> &'static [&'static str]
Returns available resource names.
Sourcepub const fn available_resources() -> &'static [Self]
pub const fn available_resources() -> &'static [Self]
Returns available resources.
Sourcepub const fn as_raw(self) -> RawResource
pub const fn as_raw(self) -> RawResource
Returns the raw resource type.
Be careful: The actual type of RawResource can be different on different platforms.
Sourceimpl Resource
impl Resource
Sourcepub const AS: Self
pub const AS: Self
The maximum size (in bytes) of the process’s virtual memory (address space).
Sourcepub const CPU: Self
pub const CPU: Self
A limit (in seconds) on the amount of CPU time that the process can consume.
Sourcepub const DATA: Self
pub const DATA: Self
The maximum size (in bytes) of the process’s data segment (initialized data, uninitialized data, and heap).
Sourcepub const LOCKS: Self
pub const LOCKS: Self
(early Linux 2.4 only)
A limit on the combined number
of flock(2) locks and fcntl(2) leases
that this process may establish.
Sourcepub const MSGQUEUE: Self
pub const MSGQUEUE: Self
A limit on the number of bytes that can be allocated for POSIX message queues for the real user ID of the calling process.
Sourcepub const NICE: Self
pub const NICE: Self
This specifies a ceiling
to which the process’s nice value can be raised
using setpriority(2) or nice(2).
Sourcepub const NOFILE: Self
pub const NOFILE: Self
This specifies a value one greater than the maximum file descriptor number that can be opened by this process.
Sourcepub const NPROC: Self
pub const NPROC: Self
A limit on the number of extant process (or, more precisely on Linux, threads) for the real user ID of the calling process.
Sourcepub const RSS: Self
pub const RSS: Self
A limit (in bytes) on the process’s resident set (the number of virtual pages resident in RAM).
Sourcepub const RTPRIO: Self
pub const RTPRIO: Self
This specifies a ceiling on the real-time priority
that may be set for this process
using sched_setscheduler(2) and sched_setparam(2).
Sourcepub const RTTIME: Self
pub const RTTIME: Self
A limit (in microseconds) on the amount of CPU time that a process scheduled under a real-time scheduling policy may consume without making a blocking system call.
Sourcepub const SIGPENDING: Self
pub const SIGPENDING: Self
A limit on the number of signals that may be queued for the real user ID of the calling process.